@@ -118,7 +118,8 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
     stream_to_sync = {}
     total_row_count = {}
     batch_size_rows = config.get('batch_size_rows', DEFAULT_BATCH_SIZE_ROWS)
-    batch_wait_limit_seconds = config.get('batch_wait_limit_seconds', DEFAULT_BATCH_WAIT_TIME)
+    batch_wait_limit_seconds = config.get(
+        'batch_wait_limit_seconds', DEFAULT_BATCH_WAIT_TIME)
     flush_timestamp = datetime.utcnow()
     archive_load_files = config.get('archive_load_files', False)
     archive_load_files_data = {}
@@ -573,7 +574,7 @@ class SnowflakeTargetConnector(C8Connector):
         """List of reserved keys for the connector."""
         return []
 
-    def config() -> List[ConfigProperty]:
+    def config(self) -> List[ConfigProperty]:
         """Get configuration parameters for the connector."""
         return [
             ConfigProperty('account', 'Account', ConfigAttributeType.STRING, True, False,
